=== modified file 'grackle/client.py'
--- grackle/client.py	2012-01-13 15:14:10 +0000
+++ grackle/client.py	2012-01-13 15:39:22 +0000
@@ -45,7 +45,7 @@
 
     def get_messages(self, archive_id, message_ids=None, limit=None,
                      memo=None, order=None, headers=None,
-                     max_body_length=None):
+                     max_body_length=None, include_hidden=False):
         parameters = {}
         if message_ids is not None:
             parameters['message_ids'] = message_ids
@@ -59,6 +59,7 @@
             parameters['headers'] = headers
         if max_body_length is not None:
             parameters['max_body_length'] = max_body_length
+        parameters['include_hidden'] = include_hidden
         query = {'parameters': simplejson.dumps(parameters)}
         response = self._verb_archive('GET', archive_id, query)
         if response.status == httplib.BAD_REQUEST:

=== modified file 'grackle/tests/test_client.py'
--- grackle/tests/test_client.py	2012-01-13 15:14:10 +0000
+++ grackle/tests/test_client.py	2012-01-13 15:39:22 +0000
@@ -61,8 +61,28 @@
             else:
                 messages.sort(key=lambda m: m[order])
         messages = [m for m in messages
-                    if 'message_ids' not in parameters or
-                    m['message_id'] in parameters['message_ids']]
+]
+        new_messages = []
+        for message in messages:
+            if (
+                not parameters['include_hidden']
+                and message.get('hidden', False)):
+                continue
+
+            if ('message_ids' in parameters and
+                message['message_id'] not in parameters['message_ids']):
+                continue
+            message = dict(message)
+            if 'headers' in parameters:
+                headers = dict(
+                    (k, v) for k, v in message['headers'].iteritems()
+                    if k in parameters['headers'])
+                message['headers'] = headers
+            max_body = parameters.get('max_body_length')
+            if max_body is not None:
+                message['body'] = message['body'][:max_body]
+            new_messages.append(message)
+        messages = new_messages
         limit = parameters.get('limit', 100)
         memo = parameters.get('memo')
         message_id_indices = dict(
@@ -81,20 +101,9 @@
         else:
             next_memo = None
         messages = messages[start:end]
-        new_messages = []
-        for message in messages:
-            message = dict(message)
-            if 'headers' in parameters:
-                headers = dict(
-                    (k, v) for k, v in message['headers'].iteritems()
-                    if k in parameters['headers'])
-                message['headers'] = headers
-            max_body = parameters.get('max_body_length')
-            if max_body is not None:
-                message['body'] = message['body'][:max_body]
-            new_messages.append(message)
+
         response = {
-            'messages': new_messages,
+            'messages': messages,
             'next_memo': next_memo,
             'previous_memo': previous_memo
             }
@@ -313,7 +322,7 @@
         self.assertEqual({}, first_message['headers'])
 
     def test_get_messages_headers_exclude_headers(self):
-        client = GrackleClient('localhost', 8440)
+        client = GrackleClient('localhost', 8441)
         with fake_grackle_service(client,
             {'baz': [
                 {'message_id': 'foo', 'headers': {'From': 'me'}}
@@ -325,7 +334,7 @@
         self.assertEqual({}, first_message['headers'])
 
     def test_get_messages_headers_include_headers(self):
-        client = GrackleClient('localhost', 8440)
+        client = GrackleClient('localhost', 8442)
         with fake_grackle_service(client,
             {'baz': [
                 {'message_id': 'foo', 'headers': {'From': 'me', 'To': 'you'}}
@@ -337,7 +346,7 @@
         self.assertEqual({'From': 'me', 'To': 'you'}, first_message['headers'])
 
     def test_get_messages_max_body_length(self):
-        client = GrackleClient('localhost', 8440)
+        client = GrackleClient('localhost', 8443)
         with fake_grackle_service(client,
             {'baz': [
                 {'message_id': 'foo', 'body': u'abcdefghi'}
@@ -346,3 +355,15 @@
         first_message = response['messages'][0]
         self.assertEqual('abc', first_message['body'])
 
+    def test_include_hidden(self):
+        client = GrackleClient('localhost', 8444)
+        with fake_grackle_service(client,
+            {'baz': [
+                {'message_id': 'foo', 'hidden': True},
+                {'message_id': 'bar', 'hidden': False}
+            ]}):
+            response = client.get_messages('baz', include_hidden=True)
+            self.assertMessageIDs(['bar', 'foo'], response['messages'])
+            response = client.get_messages('baz', include_hidden=False)
+            self.assertMessageIDs(['bar'], response['messages'])
+

